@@ -1,3 +1,6 @@
+import matplotlib
+matplotlib.use('agg')
+
 import hyperspy.api as hs
 
 hs.preferences.GUIs.enable_traitsui_gui = False
